#!/bin/sh

set -e

function stopYioop {
    if [ ! -z ${yioop_pid+x} ];
    then
        echo
        echo Stopping Yioop process .....
        kill -9 $yioop_pid
        echo
    fi
}
trap stopYioop EXIT

RANDOM=$$
mod=16384
port_start=49152
yioop_path="${1:-$PWD}/yioop"

echo Checking Firefox is installed .....
if mdfind "kMDItemKind == 'Application' && kMDItemFSName = 'Firefox.app'" > /dev/null
then
    echo
    firefox=1
else
    echo *************** Warning - Firefox not found ***************
    echo Install Firefox to run the test cases in Firefox
    firefox=0
fi

echo Checking Google Chrome is installed .....
if mdfind "kMDItemKind == 'Application' && kMDItemFSName = 'Google Chrome.app'" > /dev/null
then
    echo
    chrome=1
else
    echo *************** Warning - Google Chrome not found ***************
    echo Install Google Chrome to run the test cases in Google Chrome
    chrome=0
fi

if [ $firefox == 0 -a $chrome == 0 ]
then
    echo No browsers are installed to execute the test cases. Please install atleast Firefox or Google Chrome
    exit 1
fi

echo Checking Yioop installed at $yioop_path .....
if [ -d $yioop_path ];
then
    echo Yioop found at given path, pulling latest copy and saving at $yioop_path .....
    exist=1
    git -C $yioop_path pull
else
    echo Yioop not found, downloading latest copy .....
    exist=0
    git clone https://seekquarry.com/git/yioop.git $yioop_path
    if [ ! -d $yioop_path ]; 
    then
        echo Yioop could not be downloaded!
        exit 1
    fi
fi

if [ $exist == 0 ];
then
    echo
    echo Configuring Work Directory .....
    { echo 9; } | php "$yioop_path/src/configs/ConfigureTool.php"
    echo
    echo Setting up Users and Groups data in Yioop .....
    php "$yioop_path/tests/ManyUserExperiment.php"
fi


port=$((($RANDOM%$mod)+$port_start))
while lsof -i:$port | grep LISTEN > /dev/null
do
    port=$((($RANDOM%$mod)+$port_start))
done
echo
echo Starting Yioop instance at port $port .....
echo php "$yioop_path/index.php" child $port &
php "$yioop_path/index.php" child $port & > /dev/null
yioop_pid=$(ps -ef | grep "php $yioop_path/index.php child $port" | grep -v 'grep' | awk '{printf $2}')

echo
echo Installing required node modules .....
echo npm install
npm install

echo
echo Starting testing .....
npm test -- --firefox:$firefox --chrome:$chrome --port:$port