const chai = require('chai')
const Utils = require('../utils.js').Utils;
const {By, until} = require('selenium-webdriver');

let utils = new Utils(process.argv);

utils.mode.forEach(MODE => {
    utils.browsers.forEach(browser => {

        // Not able to open mobile site in firefox, skip this case
        if (MODE === 'mobile' && browser === 'firefox') {
            return;
        }
        
        describe(`Test Delete Group in ${browser} Browser - ${MODE}`, function() {
            let driver;
            let groupToBeDeleted = `Test ${browser} - ${MODE}` //e.g Test chrome - mobile;
            let filter;

            // before starting first test case, create driver session, 
            // then login as root and navigate to My Groups activity
            before(async function() {
                driver = utils.getBrowserDriver(browser, MODE);
                await utils.navigateToMyGroups(driver);
                await utils.takeScreenshot(driver, MODE, browser, 'group_delete_before.png');
                await driver.wait(until.elementLocated(By.className('group-title-item')), 1000);
            });

            // if any test case fails, then close the driver session
            // because the test case depends on success of previous test case
            this.afterEach(function() {
                if (this.currentTest.state === 'failed') {
                    driver.close();
                }
                utils.displayScreenshots(this);
            });

            // after all test cases are done, close the driver session
            after(function() {
                driver.close();
            });

            it('confirm filter is available', async function() {
                filter = await driver.wait(until.elementLocated(By.id('group-filter')), 1000);
                let isDisplayed = await filter.isDisplayed();
                chai.expect(isDisplayed).to.be.true;
            });

            it(`filter ${groupToBeDeleted}`, async function() {
                await filter.sendKeys(groupToBeDeleted);
                let goBtn = await driver.findElement(By.css('button'));
                let btnText = await goBtn.getText();
                chai.expect(btnText).to.equal('Go');
                await goBtn.click();
            });

            it(`confirm only ${groupToBeDeleted} is shown`, async function() {
                await driver.wait(until.elementLocated(By.className('group-title-item')), 2000);
                await utils.takeScreenshot(driver, MODE, browser, 'group_delete_filter.png');
                let groups = await driver.findElements(By.className('group-title-item'));
                chai.expect(groups.length).to.equal(1);
                chai.expect(await groups[0].getText()).to.equal(groupToBeDeleted);
            });

            it('locate delete button, if found perform click', async function() {
                let deleteBtn = await driver.findElement(By.css('span[aria-label=Delete]'));
                chai.expect(await deleteBtn.isDisplayed()).to.be.true;
                await deleteBtn.click();
            });

            it('delete alert displayed, click OK', async function() {
                await driver.wait(until.alertIsPresent(), 1000);
                let alertWindow = driver.switchTo().alert();
                await alertWindow.accept();
            });

            it(`check the message and confirm ${groupToBeDeleted} is deleted`, async function() {
                // the sync mess up in firefox when dealing with alert windows
                // as a result the delete message is not shown till this point
                // so skip that validation for firefox
                if (browser === 'chrome') {
                    await utils.takeScreenshot(driver, MODE, browser, 'group_delete_message.png');
                    let messageDiv = await driver.wait(until.elementLocated(By.id('message')), 1000);
                    chai.expect(await messageDiv.getText()).to.equal('Group Deleted');
                }
            });

        });
    });
});