const chai = require('chai');
const Utils = require('../utils.js').Utils;
const {By, until} = require('selenium-webdriver');

let utils = new Utils(process.argv);

utils.mode.forEach(MODE => {
    utils.browsers.forEach(browser => {
        
        // Not able to open mobile site in firefox, skip this case
        if (MODE === 'mobile' && browser === 'firefox') {
            return;
        }
        
        describe(`Test Signin flow in ${browser} Browser - ${MODE}`, function(){
            let driver = utils.getBrowserDriver(browser, MODE);

            // if any test case fails, then close the driver session
            // because the test case depends on success of previous test case
            afterEach(function() {
                if (this.currentTest.state === 'failed') {
                    driver.close();
                }
                utils.displayScreenshots(this);
            });

            // after all test cases are done, close the driver session
            after(function() {
                driver.close();
            });

            it('open Yioop home page', async function(){
                await driver.get(utils.HOME_PAGE_LINK);
                let pageTitle = await driver.getTitle();
                chai.expect(pageTitle).to.equal('This Search Engine - This Site');
                await utils.takeScreenshot(driver, MODE, browser, 'signin_home_page.png');
            });

            it('locate signin Link, if found perform click', async function(){
                await driver.findElement(By.id('settings-toggle-icon')).click();
                let signinLink = await driver.findElement(By.xpath('//*[@id="welcome-menu-options"]/ul/li[1]/a'));
                await driver.wait(until.elementIsVisible(signinLink), 1000);
                let signinText = await signinLink.getText();
                chai.expect(signinText).to.equal('Signin');
                await utils.takeScreenshot(driver, MODE, browser, 'signin_menu_options.png');
                await signinLink.click();
            });

            it('confirm signin page is available', async function(){
                let signinForm = await driver.findElement(By.xpath('//*[@id="body-container"]/div[2]/form'));
                await driver.wait(until.elementIsVisible(signinForm), 1000);
                let formExists = await signinForm.isDisplayed();
                chai.expect(formExists).to.be.true;
                await utils.takeScreenshot(driver, MODE, browser, 'signin_login_form.png');
            });

            it('signin using root', async function(){
                await driver.findElement(By.id('username')).sendKeys('root');
                await driver.findElement(By.id('password')).sendKeys('');
                await driver.findElement(By.css('button')).click();
                let messageDiv = driver.findElement(By.id('message'));
                await driver.wait(until.elementIsVisible(messageDiv), 1000);
                let message = await messageDiv.getText();
                chai.expect(message).to.equal('Login Successful!!');
                await utils.takeScreenshot(driver, MODE, browser, 'signin_account_page.png');
            });

            it('account page is available, confirm the username displayed', async function(){
                //the username displayed on top of the toggle menu options
                let usernameDiv = await driver.findElement(By.css('div[class=top]'));
                await driver.wait(until.elementIsVisible(usernameDiv), 1000);
                let displayedUserName = await usernameDiv.getText();
                chai.expect(displayedUserName).to.equal('[root]');
                await driver.close();
            });

        });
    });
});